[Openchrome-devel] xf86-video-openchrome: 11 commits - configure.ac src/via_fp.c src/via_outputs.c src/via_tmds.c src/via_tv.c src/via_ums.h

Kevin Brace kevinbrace at kemper.freedesktop.org
Sun Jun 11 23:41:01 UTC 2017


 configure.ac      |    2 -
 src/via_fp.c      |  103 ++----------------------------------------------------
 src/via_outputs.c |   26 -------------
 src/via_tmds.c    |    4 +-
 src/via_tv.c      |    2 -
 src/via_ums.h     |   61 +++++++++++++++++++++++++++++++
 6 files changed, 69 insertions(+), 129 deletions(-)

New commits:
commit 21c64d312e3a288cc5fd2b4b4c8c8f1a729bb777
Author: Kevin Brace <kevinbrace at gmx.com>
Date:   Sun Jun 11 16:40:34 2017 -0700

    Version bumped to 0.6.136
    
    Signed-off-by: Kevin Brace <kevinbrace at gmx.com>

diff --git a/configure.ac b/configure.ac
index 7955e7e..c9a9abd 100644
--- a/configure.ac
+++ b/configure.ac
@@ -23,7 +23,7 @@
 # Initialize Autoconf
 AC_PREREQ(2.57)
 AC_INIT([xf86-video-openchrome],
-        [0.6.135],
+        [0.6.136],
         [https://bugs.freedesktop.org/enter_bug.cgi?product=xorg&component=Driver/openchrome],
         [xf86-video-openchrome])
 
commit 77dab83dff274cc16cf580461467821fac1dd6eb
Author: Kevin Brace <kevinbrace at gmx.com>
Date:   Sun Jun 11 16:39:10 2017 -0700

    Resolved implicit declaration of viaDFPLowSetDisplaySource
    
    Signed-off-by: Kevin Brace <kevinbrace at gmx.com>

diff --git a/src/via_tmds.c b/src/via_tmds.c
index a622859..1b7ac4d 100644
--- a/src/via_tmds.c
+++ b/src/via_tmds.c
@@ -312,7 +312,7 @@ viaExtTMDSSetDisplaySource(ScrnInfoPtr pScrn, CARD8 displaySource)
         if ((sr12 & 0x40) && (!(sr12 & 0x20))) {
             viaDVP0SetDisplaySource(pScrn, displaySource);
         } else if ((sr13 & 0x08) && (!(sr12 & 0x10))) {
-            viaDFPLowSetDisplaySource(pScrn, displaySource);
+            viaFPDPLowSetDisplaySource(pScrn, displaySource);
         } else {
             xf86DrvMsg(pScrn->scrnIndex, X_ERROR,
                         "None of the external ports were set up for "
@@ -332,7 +332,7 @@ viaExtTMDSSetDisplaySource(ScrnInfoPtr pScrn, CARD8 displaySource)
         if ((sr12 & 0x40) && (!(sr12 & 0x20))) {
             viaDVP0SetDisplaySource(pScrn, displaySource);
         } else if (!(sr12 & 0x10)) {
-            viaDFPLowSetDisplaySource(pScrn, displaySource);
+            viaFPDPLowSetDisplaySource(pScrn, displaySource);
         } else {
             xf86DrvMsg(pScrn->scrnIndex, X_ERROR,
                         "None of the external ports were set up for "
diff --git a/src/via_tv.c b/src/via_tv.c
index 23d1428..e105148 100644
--- a/src/via_tv.c
+++ b/src/via_tv.c
@@ -106,7 +106,7 @@ viaTVSetDisplaySource(ScrnInfoPtr pScrn, CARD8 displaySource)
         if ((sr12 & 0x40) && (sr12 & 0x20)) {
             viaDVP0SetDisplaySource(pScrn, displaySource);
         } else if ((sr13 & 0x08) && (!(sr12 & 0x10))) {
-            viaDFPLowSetDisplaySource(pScrn, displaySource);
+            viaFPDPLowSetDisplaySource(pScrn, displaySource);
         } else if (sr13 & 0x08) {
             viaDVP1SetDisplaySource(pScrn, displaySource);
         } else {
commit fa33a026adf1249ebfa20f04875eb27d11a42d9c
Author: Kevin Brace <kevinbrace at gmx.com>
Date:   Sun Jun 11 16:36:11 2017 -0700

    Converted viaFPDPHighSetDelayTap to an inline function
    
    Signed-off-by: Kevin Brace <kevinbrace at gmx.com>

diff --git a/src/via_fp.c b/src/via_fp.c
index e4afd66..ff576a7 100644
--- a/src/via_fp.c
+++ b/src/via_fp.c
@@ -105,28 +105,6 @@ static DisplayModeRec OLPCMode = {
 #define TD2 0
 #define TD3 25
 
-/*
- * Sets FPDP (Flat Panel Display Port) High interface delay tap.
- */
-static void
-viaFPDPHighSetDelayTap(ScrnInfoPtr pScrn, CARD8 delayTap)
-{
-    vgaHWPtr hwp = VGAHWPTR(pScrn);
-
-    DEBUG(xf86DrvMsg(pScrn->scrnIndex, X_INFO,
-                        "Entered viaFPDPHighSetDelayTap.\n"));
-
-    /* Set FPDP High interface delay tap. */
-    /* 3X5.97[3:0] - FPDP High Delay Tap */
-    ViaCrtcMask(hwp, 0x97, delayTap, 0x0F);
-    xf86DrvMsg(pScrn->scrnIndex, X_INFO,
-                "FPDP High Delay Tap: %d\n",
-                (delayTap & 0x0F));
-
-    DEBUG(xf86DrvMsg(pScrn->scrnIndex, X_INFO,
-                        "Exiting viaFPDPHighSetDelayTap.\n"));
-}
-
 static void
 viaFPIOPadState(ScrnInfoPtr pScrn, CARD8 diPort, Bool ioPadOn)
 {
diff --git a/src/via_ums.h b/src/via_ums.h
index f732088..312a558 100644
--- a/src/via_ums.h
+++ b/src/via_ums.h
@@ -586,6 +586,21 @@ viaFPDPHighSetIOPadState(ScrnInfoPtr pScrn, CARD8 ioPadState)
 }
 
 /*
+ * Sets FPDP (Flat Panel Display Port) High interface delay tap.
+ */
+static inline void
+viaFPDPHighSetDelayTap(ScrnInfoPtr pScrn, CARD8 delayTap)
+{
+    /* 3X5.97[3:0] - FPDP High Delay Tap */
+    ViaCrtcMask(VGAHWPTR(pScrn), 0x97, delayTap,
+                BIT(3) | BIT(2) | BIT(1) | BIT(0));
+    DEBUG(xf86DrvMsg(pScrn->scrnIndex, X_INFO,
+                        "FPDP High Delay Tap: %d\n",
+                        (delayTap & (BIT(3) | BIT(2) |
+                                     BIT(1) | BIT(0)))));
+}
+
+/*
  * Sets FPDP (Flat Panel Display Port) High interface display source.
  */
 static inline void
commit 817a15870c9cdc3452c85f43975e08d37aa0324f
Author: Kevin Brace <kevinbrace at gmx.com>
Date:   Sun Jun 11 15:53:22 2017 -0700

    Renamed viaDFPHighSetDelayTap as viaFPDPHighSetDelayTap
    
    Signed-off-by: Kevin Brace <kevinbrace at gmx.com>

diff --git a/src/via_fp.c b/src/via_fp.c
index 0a2b509..45bab8d 100644
--- a/src/via_fp.c
+++ b/src/via_fp.c
@@ -106,28 +106,6 @@ static DisplayModeRec OLPCMode = {
 #define TD3 25
 
 /*
- * Sets FPDP (Flat Panel Display Port) Low interface delay tap.
- */
-static void
-viaFPDPLowSetDelayTap(ScrnInfoPtr pScrn, CARD8 delayTap)
-{
-    vgaHWPtr hwp = VGAHWPTR(pScrn);
-
-    DEBUG(xf86DrvMsg(pScrn->scrnIndex, X_INFO,
-                        "Entered viaFPDPLowSetDelayTap.\n"));
-
-    /* Set FPDP Low interface delay tap. */
-    /* 3X5.99[3:0] - FPDP Low Delay Tap */
-    ViaCrtcMask(hwp, 0x99, delayTap, 0x0F);
-    xf86DrvMsg(pScrn->scrnIndex, X_INFO,
-                "FPDP Low Delay Tap: %d\n",
-                (delayTap & 0x0F));
-
-    DEBUG(xf86DrvMsg(pScrn->scrnIndex, X_INFO,
-                        "Exiting viaFPDPLowSetDelayTap.\n"));
-}
-
-/*
  * Sets DFP (Digital Flat Panel) High interface delay tap.
  */
 static void
diff --git a/src/via_ums.h b/src/via_ums.h
index 9ec6297..f732088 100644
--- a/src/via_ums.h
+++ b/src/via_ums.h
@@ -536,6 +536,21 @@ viaFPDPLowSetIOPadState(ScrnInfoPtr pScrn, CARD8 ioPadState)
 }
 
 /*
+ * Sets FPDP (Flat Panel Display Port) Low interface delay tap.
+ */
+static inline void
+viaFPDPLowSetDelayTap(ScrnInfoPtr pScrn, CARD8 delayTap)
+{
+    /* 3X5.99[3:0] - FPDP Low Delay Tap */
+    ViaCrtcMask(VGAHWPTR(pScrn), 0x99, delayTap,
+                BIT(3) | BIT(2) | BIT(1) | BIT(0));
+    DEBUG(xf86DrvMsg(pScrn->scrnIndex, X_INFO,
+                        "FPDP Low Delay Tap: %d\n",
+                        (delayTap & (BIT(3) | BIT(2) |
+                                     BIT(1) | BIT(0)))));
+}
+
+/*
  * Sets FPDP (Flat Panel Display Port) Low interface display source.
  */
 static inline void
commit 67998f81a211aa638756d9fe0ae7f7d14fa99984
Author: Kevin Brace <kevinbrace at gmx.com>
Date:   Sun Jun 11 15:13:20 2017 -0700

    Renamed viaDFPLowSetDelayTap as viaFPDPLowSetDelayTap
    
    Signed-off-by: Kevin Brace <kevinbrace at gmx.com>

diff --git a/src/via_fp.c b/src/via_fp.c
index 071d00d..173b59a 100644
--- a/src/via_fp.c
+++ b/src/via_fp.c
@@ -106,29 +106,6 @@ static DisplayModeRec OLPCMode = {
 #define TD3 25
 
 /*
- * Sets LVDS2 (LVDS Channel 2) integrated LVDS transmitter delay tap.
- */
-static void
-viaLVDS2SetDelayTap(ScrnInfoPtr pScrn, CARD8 delayTap)
-{
-    vgaHWPtr hwp = VGAHWPTR(pScrn);
-
-    DEBUG(xf86DrvMsg(pScrn->scrnIndex, X_INFO,
-                        "Entered viaLVDS2SetDelayTap.\n"));
-
-    /* Set LVDS2 delay tap. */
-    /* 3X5.97[3:0] - LVDS2 Delay Tap */
-    ViaCrtcMask(hwp, 0x97, delayTap, 0x0F);
-
-    xf86DrvMsg(pScrn->scrnIndex, X_INFO,
-                "LVDS2 Delay Tap: %d\n",
-                (delayTap & 0x0F));
-
-    DEBUG(xf86DrvMsg(pScrn->scrnIndex, X_INFO,
-                        "Exiting viaLVDS2SetDelayTap.\n"));
-}
-
-/*
  * Sets DFP (Digital Flat Panel) Low interface delay tap.
  */
 static void
commit 26f6b251edd50e42ba5499d24e3acd99f10e0106
Author: Kevin Brace <kevinbrace at gmx.com>
Date:   Sun Jun 11 15:06:13 2017 -0700

    Renamed viaDFPHighSetDisplaySource as viaFPDPHighSetDisplaySource
    
    Signed-off-by: Kevin Brace <kevinbrace at gmx.com>

diff --git a/src/via_fp.c b/src/via_fp.c
index a04e722..071d00d 100644
--- a/src/via_fp.c
+++ b/src/via_fp.c
@@ -321,13 +321,13 @@ viaFPDisplaySource(ScrnInfoPtr pScrn, CARD8 diPort, int index)
         viaDVP1SetDisplaySource(pScrn, displaySource);
         break;
     case VIA_DI_PORT_FPDPHIGH:
-        viaDFPHighSetDisplaySource(pScrn, displaySource);
+        viaFPDPHighSetDisplaySource(pScrn, displaySource);
         viaDVP0SetDisplaySource(pScrn, displaySource);
         break;
     case (VIA_DI_PORT_FPDPLOW |
           VIA_DI_PORT_FPDPHIGH):
         viaFPDPLowSetDisplaySource(pScrn, displaySource);
-        viaDFPHighSetDisplaySource(pScrn, displaySource);
+        viaFPDPHighSetDisplaySource(pScrn, displaySource);
         break;
     case VIA_DI_PORT_LVDS1:
         viaLVDS1SetDisplaySource(pScrn, displaySource);
diff --git a/src/via_fp.c b/src/via_fp.c
index 47e5086..a04e722 100644
--- a/src/via_fp.c
+++ b/src/via_fp.c
@@ -317,7 +317,7 @@ viaFPDisplaySource(ScrnInfoPtr pScrn, CARD8 diPort, int index)
         viaDVP1SetDisplaySource(pScrn, displaySource);
         break;
     case VIA_DI_PORT_FPDPLOW:
-        viaDFPLowSetDisplaySource(pScrn, displaySource);
+        viaFPDPLowSetDisplaySource(pScrn, displaySource);
         viaDVP1SetDisplaySource(pScrn, displaySource);
         break;
     case VIA_DI_PORT_FPDPHIGH:
@@ -326,7 +326,7 @@ viaFPDisplaySource(ScrnInfoPtr pScrn, CARD8 diPort, int index)
         break;
     case (VIA_DI_PORT_FPDPLOW |
           VIA_DI_PORT_FPDPHIGH):
-        viaDFPLowSetDisplaySource(pScrn, displaySource);
+        viaFPDPLowSetDisplaySource(pScrn, displaySource);
         viaDFPHighSetDisplaySource(pScrn, displaySource);
         break;
     case VIA_DI_PORT_LVDS1:
diff --git a/src/via_fp.c b/src/via_fp.c
index 6cf40fd..47e5086 100644
--- a/src/via_fp.c
+++ b/src/via_fp.c
@@ -129,32 +129,6 @@ viaLVDS2SetDelayTap(ScrnInfoPtr pScrn, CARD8 delayTap)
 }
 
 /*
- * Sets IGA1 or IGA2 as the display output source for VIA Technologies
- * Chrome IGP DFP (Digital Flat Panel) High interface.
- */
-static void
-viaDFPHighSetDisplaySource(ScrnInfoPtr pScrn, CARD8 displaySource)
-{
-    vgaHWPtr hwp = VGAHWPTR(pScrn);
-    CARD8 temp = displaySource;
-
-    DEBUG(xf86DrvMsg(pScrn->scrnIndex, X_INFO,
-                        "Entered viaDFPHighSetDisplaySource.\n"));
-
-    /* Set DFP High display output source. */
-    /* 3X5.97[4] - DFP High Data Source Selection
-     *             0: Primary Display
-     *             1: Secondary Display */
-    ViaCrtcMask(hwp, 0x97, temp << 4, 0x10);
-    xf86DrvMsg(pScrn->scrnIndex, X_INFO,
-                "DFP High Display Output Source: IGA%d\n",
-                (temp & 0x01) + 1);
-
-    DEBUG(xf86DrvMsg(pScrn->scrnIndex, X_INFO,
-                        "Exiting viaDFPHighSetDisplaySource.\n"));
-}
-
-/*
  * Sets DFP (Digital Flat Panel) Low interface delay tap.
  */
 static void
diff --git a/src/via_ums.h b/src/via_ums.h
index c49f842..e407ff5 100644
--- a/src/via_ums.h
+++ b/src/via_ums.h
@@ -571,6 +571,21 @@ viaFPDPHighSetIOPadState(ScrnInfoPtr pScrn, CARD8 ioPadState)
 }
 
 /*
+ * Sets DFP (Digital Flat Panel) High interface display source.
+ */
+static inline void
+viaDFPHighSetDisplaySource(ScrnInfoPtr pScrn, CARD8 displaySource)
+{
+    /* 3X5.97[4] - DFP High Data Source Selection
+     *             0: Primary Display
+     *             1: Secondary Display */
+    ViaCrtcMask(VGAHWPTR(pScrn), 0x97, displaySource << 4, BIT(4));
+    xf86DrvMsg(pScrn->scrnIndex, X_INFO,
+                "DFP High Display Source: IGA%d\n",
+                (displaySource & 0x01) + 1);
+}
+
+/*
  * Sets CX700 or later chipset's LVDS1 power state.
  */
 static inline void
commit ec66f5d16aae0ec308ef2239224e61da65af7ea3
Author: Kevin Brace <kevinbrace at gmx.com>
Date:   Sun Jun 11 12:29:20 2017 -0700

    Converted viaDFPLowSetDisplaySource to an inline function
    
    Signed-off-by: Kevin Brace <kevinbrace at gmx.com>

diff --git a/src/via_outputs.c b/src/via_outputs.c
index 2d2fb9e..cc19961 100644
--- a/src/via_outputs.c
+++ b/src/via_outputs.c
@@ -250,32 +250,6 @@ viaDVP1SetDataDriveStrength(ScrnInfoPtr pScrn, CARD8 dataDriveStrength)
 }
 
 /*
- * Sets IGA1 or IGA2 as the display output source for VIA Technologies
- * Chrome IGP DFP (Digital Flat Panel) Low interface.
- */
-void
-viaDFPLowSetDisplaySource(ScrnInfoPtr pScrn, CARD8 displaySource)
-{
-    vgaHWPtr hwp = VGAHWPTR(pScrn);
-    CARD8 temp = displaySource;
-
-    DEBUG(xf86DrvMsg(pScrn->scrnIndex, X_INFO,
-                        "Entered viaDFPLowSetDisplaySource.\n"));
-
-    /* Set DFP Low display output source. */
-    /* 3X5.99[4] - DFP Low Data Source Selection
-     *             0: Primary Display
-     *             1: Secondary Display */
-    ViaCrtcMask(hwp, 0x99, temp << 4, 0x10);
-    xf86DrvMsg(pScrn->scrnIndex, X_INFO,
-                "DFP Low Display Output Source: IGA%d\n",
-                (temp & 0x01) + 1);
-
-    DEBUG(xf86DrvMsg(pScrn->scrnIndex, X_INFO,
-                        "Exiting viaDFPLowSetDisplaySource.\n"));
-}
-
-/*
  * Sets DFP (Digital Flat Panel) Low I/O pad state.
  */
 void
diff --git a/src/via_ums.h b/src/via_ums.h
index 85656b1..c49f842 100644
--- a/src/via_ums.h
+++ b/src/via_ums.h
@@ -536,6 +536,21 @@ viaFPDPLowSetIOPadState(ScrnInfoPtr pScrn, CARD8 ioPadState)
 }
 
 /*
+ * Sets DFP (Digital Flat Panel) Low interface display source.
+ */
+static inline void
+viaDFPLowSetDisplaySource(ScrnInfoPtr pScrn, CARD8 displaySource)
+{
+    /* 3X5.99[4] - DFP Low Data Source Selection
+     *             0: Primary Display
+     *             1: Secondary Display */
+    ViaCrtcMask(VGAHWPTR(pScrn), 0x99, displaySource << 4, BIT(4));
+    DEBUG(xf86DrvMsg(pScrn->scrnIndex, X_INFO,
+                        "DFP Low Display Source: IGA%d\n",
+                        (displaySource & 0x01) + 1));
+}
+
+/*
  * Sets FPDP (Flat Panel Display Port) High I/O pad state
  */
 static inline void
@@ -888,7 +903,6 @@ void viaDVP1SetClockDriveStrength(ScrnInfoPtr pScrn,
                                     CARD8 clockDriveStrength);
 void viaDVP1SetDataDriveStrength(ScrnInfoPtr pScrn,
                                     CARD8 dataDriveStrength);
-void viaDFPLowSetDisplaySource(ScrnInfoPtr pScrn, CARD8 displaySource);
 void viaDFPLowEnableIOPads(ScrnInfoPtr pScrn, CARD8 ioPadState);
 void viaInitDisplay(ScrnInfoPtr pScrn);
 CARD32 ViaGetMemoryBandwidth(ScrnInfoPtr pScrn);


More information about the Openchrome-devel mailing list
diff --git a/src/via_fp.c b/src/via_fp.c
index 45bab8d..e4afd66 100644
--- a/src/via_fp.c
+++ b/src/via_fp.c
@@ -106,25 +106,25 @@ static DisplayModeRec OLPCMode = {
 #define TD3 25
 
 /*
  * Sets DFP (Digital Flat Panel) High interface delay tap.
  */
 static void
-viaDFPHighSetDelayTap(ScrnInfoPtr pScrn, CARD8 delayTap)
+viaFPDPHighSetDelayTap(ScrnInfoPtr pScrn, CARD8 delayTap)
 {
     vgaHWPtr hwp = VGAHWPTR(pScrn);
 
     DEBUG(xf86DrvMsg(pScrn->scrnIndex, X_INFO,
-                        "Entered viaDFPHighSetDelayTap.\n"));
+                        "Entered viaFPDPHighSetDelayTap.\n"));
 
     /* Set DFP High interface delay tap. */
     /* 3X5.97[3:0] - DFP High Delay Tap */
     ViaCrtcMask(hwp, 0x97, delayTap, 0x0F);
     xf86DrvMsg(pScrn->scrnIndex, X_INFO,
-                "DFP High Delay Tap: %d\n",
+                "FPDP High Delay Tap: %d\n",
                 (delayTap & 0x0F));
 
     DEBUG(xf86DrvMsg(pScrn->scrnIndex, X_INFO,
-                        "Exiting viaDFPHighSetDelayTap.\n"));
+                        "Exiting viaFPDPHighSetDelayTap.\n"));
 }
 
 static void
@@ -106,25 +106,25 @@ static DisplayModeRec OLPCMode = {
 
 /*
- * Sets DFP (Digital Flat Panel) High interface delay tap.
+ * Sets FPDP (Flat Panel Display Port) High interface delay tap.
  */
 static void
@@ -106,25 +106,25 @@ static DisplayModeRec OLPCMode = {
 
-    /* Set DFP High interface delay tap. */
-    /* 3X5.97[3:0] - DFP High Delay Tap */
+    /* Set FPDP High interface delay tap. */
+    /* 3X5.97[3:0] - FPDP High Delay Tap */
     ViaCrtcMask(hwp, 0x97, delayTap, 0x0F);
     xf86DrvMsg(pScrn->scrnIndex, X_INFO,
commit 75d1ec52426a1731a163a66587aebf4a89dfc886
Author: Kevin Brace <kevinbrace at gmx.com>
Date:   Sun Jun 11 15:26:56 2017 -0700

    Converted viaFPDPLowSetDelayTap to an inline function
    
    Signed-off-by: Kevin Brace <kevinbrace at gmx.com>

diff --git a/src/via_fp.c b/src/via_fp.c
index 173b59a..0a2b509 100644
--- a/src/via_fp.c
+++ b/src/via_fp.c
@@ -106,25 +106,25 @@ static DisplayModeRec OLPCMode = {
 #define TD3 25
 
 /*
  * Sets DFP (Digital Flat Panel) Low interface delay tap.
  */
 static void
-viaDFPLowSetDelayTap(ScrnInfoPtr pScrn, CARD8 delayTap)
+viaFPDPLowSetDelayTap(ScrnInfoPtr pScrn, CARD8 delayTap)
 {
     vgaHWPtr hwp = VGAHWPTR(pScrn);
 
     DEBUG(xf86DrvMsg(pScrn->scrnIndex, X_INFO,
-                        "Entered viaDFPLowSetDelayTap.\n"));
+                        "Entered viaFPDPLowSetDelayTap.\n"));
 
     /* Set DFP Low interface delay tap. */
     /* 3X5.99[3:0] - DFP Low Delay Tap */
     ViaCrtcMask(hwp, 0x99, delayTap, 0x0F);
     xf86DrvMsg(pScrn->scrnIndex, X_INFO,
-                "DFP Low Delay Tap: %d\n",
+                "FPDP Low Delay Tap: %d\n",
                 (delayTap & 0x0F));
 
     DEBUG(xf86DrvMsg(pScrn->scrnIndex, X_INFO,
-                        "Exiting viaDFPLowSetDelayTap.\n"));
+                        "Exiting viaFPDPLowSetDelayTap.\n"));
 }
 
 /*
@@ -947,7 +947,7 @@ via_fp_mode_set(xf86OutputPtr output, DisplayModePtr mode,
 
         switch (pVia->Chipset) {
         case VIA_P4M900:
-            viaDFPLowSetDelayTap(pScrn, 0x08);
+            viaFPDPLowSetDelayTap(pScrn, 0x08);
             break;
         default:
             break;
@@ -106,25 +106,25 @@ static DisplayModeRec OLPCMode = {
 
 /*
- * Sets DFP (Digital Flat Panel) Low interface delay tap.
+ * Sets FPDP (Flat Panel Display Port) Low interface delay tap.
  */
 static void
@@ -106,25 +106,25 @@ static DisplayModeRec OLPCMode = {
 
-    /* Set DFP Low interface delay tap. */
-    /* 3X5.99[3:0] - DFP Low Delay Tap */
+    /* Set FPDP Low interface delay tap. */
+    /* 3X5.99[3:0] - FPDP Low Delay Tap */
     ViaCrtcMask(hwp, 0x99, delayTap, 0x0F);
     xf86DrvMsg(pScrn->scrnIndex, X_INFO,
commit ff4e13130938eab4ed1d2b405860978f519cd32d
Author: Kevin Brace <kevinbrace at gmx.com>
Date:   Sun Jun 11 15:08:06 2017 -0700

    Removed viaLVDS2SetDelayTap
    
    Signed-off-by: Kevin Brace <kevinbrace at gmx.com>

diff --git a/src/via_ums.h b/src/via_ums.h
index 77bef6e..9ec6297 100644
--- a/src/via_ums.h
+++ b/src/via_ums.h
@@ -571,17 +571,17 @@ viaFPDPHighSetIOPadState(ScrnInfoPtr pScrn, CARD8 ioPadState)
 }
 
 /*
  * Sets DFP (Digital Flat Panel) High interface display source.
  */
 static inline void
-viaDFPHighSetDisplaySource(ScrnInfoPtr pScrn, CARD8 displaySource)
+viaFPDPHighSetDisplaySource(ScrnInfoPtr pScrn, CARD8 displaySource)
 {
     /* 3X5.97[4] - DFP High Data Source Selection
      *             0: Primary Display
      *             1: Secondary Display */
     ViaCrtcMask(VGAHWPTR(pScrn), 0x97, displaySource << 4, BIT(4));
     xf86DrvMsg(pScrn->scrnIndex, X_INFO,
-                "DFP High Display Source: IGA%d\n",
+                "FPDP High Display Source: IGA%d\n",
                 (displaySource & 0x01) + 1);
 }
 
@@ -571,17 +571,17 @@ viaFPDPHighSetIOPadState(ScrnInfoPtr pScrn, CARD8 ioPadState)
 
 /*
- * Sets DFP (Digital Flat Panel) High interface display source.
+ * Sets FPDP (Flat Panel Display Port) High interface display source.
  */
 static inline void
@@ -571,17 +571,17 @@ viaFPDPHighSetIOPadState(ScrnInfoPtr pScrn, CARD8 ioPadState)
 {
-    /* 3X5.97[4] - DFP High Data Source Selection
+    /* 3X5.97[4] - FPDP High Data Source Selection
      *             0: Primary Display
      *             1: Secondary Display */
commit 6cdb5fc6aeea84db90b7375c213df2f531e891e2
Author: Kevin Brace <kevinbrace at gmx.com>
Date:   Sun Jun 11 15:02:01 2017 -0700

    Renamed viaDFPLowSetDisplaySource as viaFPDPLowSetDisplaySource
    
    Signed-off-by: Kevin Brace <kevinbrace at gmx.com>

diff --git a/src/via_ums.h b/src/via_ums.h
index e407ff5..77bef6e 100644
--- a/src/via_ums.h
+++ b/src/via_ums.h
@@ -536,17 +536,17 @@ viaFPDPLowSetIOPadState(ScrnInfoPtr pScrn, CARD8 ioPadState)
 }
 
 /*
  * Sets DFP (Digital Flat Panel) Low interface display source.
  */
 static inline void
-viaDFPLowSetDisplaySource(ScrnInfoPtr pScrn, CARD8 displaySource)
+viaFPDPLowSetDisplaySource(ScrnInfoPtr pScrn, CARD8 displaySource)
 {
     /* 3X5.99[4] - DFP Low Data Source Selection
      *             0: Primary Display
      *             1: Secondary Display */
     ViaCrtcMask(VGAHWPTR(pScrn), 0x99, displaySource << 4, BIT(4));
     DEBUG(xf86DrvMsg(pScrn->scrnIndex, X_INFO,
-                        "DFP Low Display Source: IGA%d\n",
+                        "FPDP Low Display Source: IGA%d\n",
                         (displaySource & 0x01) + 1));
 }
 
@@ -536,17 +536,17 @@ viaFPDPLowSetIOPadState(ScrnInfoPtr pScrn, CARD8 ioPadState)
 
 /*
- * Sets DFP (Digital Flat Panel) Low interface display source.
+ * Sets FPDP (Flat Panel Display Port) Low interface display source.
  */
 static inline void
@@ -536,17 +536,17 @@ viaFPDPLowSetIOPadState(ScrnInfoPtr pScrn, CARD8 ioPadState)
 {
-    /* 3X5.99[4] - DFP Low Data Source Selection
+    /* 3X5.99[4] - FPDP Low Data Source Selection
      *             0: Primary Display
      *             1: Secondary Display */
commit 87eb4dd101003adc657b8690dae71636cd076c76
Author: Kevin Brace <kevinbrace at gmx.com>
Date:   Sun Jun 11 12:37:50 2017 -0700

    Converted viaDFPHighSetDisplaySource to an inline function
    
    Signed-off-by: Kevin Brace <kevinbrace at gmx.com>
